@@ -10,13 +10,13 @@
         
 def guessMetricByType(mainDict:dict, checkDict:dict):
     if "units" not in mainDict:
-        mainDict["units"] = {}
+        mainDict = {}
     for i in checkDict:
         try:
             int(checkDict[i])
-            mainDict["units"][i] = 'count'
+            mainDict[i] = 'count'
         except ValueError:
-            mainDict["units"][i] = 'string'
+            mainDict[i] = 'string'
 
 ##validation method - This is only for Output validation purpose
 def validatePluginData(result):
